@@ -97,7 +97,7 @@ class RegexDataFinder(BaseDataFinder):
         else:
             self.to_line = None
 
-        if self.from_line and self.to_line and self.from_line >= self.to_line:
+        if self.from_line and self.to_line and self.from_line > self.to_line:
             raise Exception(
                 "from_line ({}) should not be greater than to_line "
                 "({})".format(self.from_line, self.to_line)
@@ -209,7 +209,7 @@ class FrNameRegexDataFinder(RegexDataFinder):
     """
     def __init__(self, **kw):
         kw['regex'] = (
-            r"[ ]+(M|Mme|Mlle|Madame|Monsieur|Mademoiselle)[ ]+(?P<name>"
+            r"[ ]+(i?)(M|Mme|Mlle|Madame|Monsieur|Mademoiselle)[ ]+(?P<name>"
             r"[-\w ']+)(\n|$)")
         kw['regex_group_name'] = 'name'
         RegexDataFinder.__init__(self, **kw)
