@@ -9,22 +9,17 @@ import unicodedata
 
 from collections import OrderedDict
 from tempfile import mkstemp
-from subprocess import Popen, PIPE
 
 from .log_config import flag_report
 import shutil
 
 from PyPDF4 import PdfFileReader, PdfFileWriter
 
-from .config import (
-    Error as ConfigError
-)
 from .utils import (
     get_command_outputs,
     mkdir_p,
 )
 from .errors import (
-    AutosplitError,
     Incoherence,
     ParseError,
 )
@@ -62,11 +57,7 @@ class PdfSplitter(object):
         )
         self.pb_dir = self.config.getvalue('pb_dir')
 
-        self.preprocessor = self.config.getvalue(('preprocessor', 'payroll'))
-        # if not os.path.exists(self.preprocessor):
-        #     raise ConfigError(
-        #         "payroll preprocessor: %s - file not found"
-        #         % self.preprocessor)
+        self.preprocessor = self.config.getvalue('preprocessor')
 
     def _collect_page_indexes(self, filepath):
         """
@@ -106,7 +97,7 @@ class PdfSplitter(object):
                 if None in match_values:
                     self.logger.critical(
                         "Unable to extract data from "
-                        "page {} (extracted {})".format(page_nb, page_data)
+                        "page {}".format(page_nb)
                     )
                     break
 
@@ -241,7 +232,7 @@ class PdfSplitter(object):
             except OSError:
                 self.logger.critical(
                     "Error while trying to run '%s'",
-                    ' '.join(argv_seq))
+                    ' '.join(command))
                 raise
             self.logger.critical(stdout.strip())
             return {}
@@ -270,6 +261,10 @@ class PdfSplitter(object):
                     )
                 )
                 break
+            else:
+                self.logger.debug("Not found with {} data finder".format(
+                    data_name,
+                ))
         return result
 
     def _get_page_data(self, filepath, pagenb):
@@ -324,7 +319,7 @@ class PdfSplitter(object):
         except OSError:
             self.logger.critical(
                 "Error while trying to run '%s'",
-                ' '.join(argv_seq))
+                ' '.join(command))
             raise
         strcommand = " ".join(command)
         if returncode != 0:
@@ -357,7 +352,7 @@ class PdfSplitter(object):
         except OSError:
             self.logger.critical(
                 "Error while trying to run '%s'",
-                ' '.join(argv_seq))
+                ' '.join(command))
             raise
 
         if returncode != 0:
